@@ -144,7 +144,7 @@ class Command(BaseCommand):
         repetidas = 0
         descargadas = 0
         total = 0
-        thumbs = [200, 750, 1000]
+        thumbs = [60, 200, 750, 1000]
         if storage == 'dropbox':
             srcdir = os.path.join(conf.PROJECT_DIR, 'media', 'uploads', 'dropbox')
         if storage == 'file':
